@@ -1,21 +1,21 @@
 package Apache::DBI;
-
-use Apache ();
-use DBI ();
 use strict;
 
-# $Id: DBI.pm,v 1.2 2002/06/18 05:50:19 ask Exp $
+# $Id: DBI.pm,v 1.6 2003/02/17 13:04:19 ask Exp $
+
+BEGIN { eval { require Apache } }
+use DBI ();
+use Carp qw(carp);
 
 require_version DBI 1.00;
 
-$Apache::DBI::VERSION = '0.89';
+$Apache::DBI::VERSION = '0.91';
 
 # 1: report about new connect
 # 2: full debug output
 $Apache::DBI::DEBUG = 0;
 #DBI->trace(2);
 
-
 my %Connected;    # cache for database handles
 my @ChildConnect; # connections to be established when a new httpd child is created
 my %Rollback;     # keeps track of pushed PerlCleanupHandler which can do a rollback after the request has finished
@@ -30,6 +30,9 @@ my $Idx;          # key of %Connected and %Rollback.
 
 sub connect_on_init { 
     # provide a handler which creates all connections during server startup
+
+    # TODO - Should check for mod_perl 2 and do the right thing there
+    carp "Apache.pm was not loaded\n" and return unless $INC{'Apache.pm'};
     if(!@ChildConnect and Apache->can('push_handlers')) {
         Apache->push_handlers(PerlChildInitHandler => \&childinit);
     }
@@ -85,6 +88,7 @@ sub connect {
 
     # this PerlCleanupHandler is supposed to initiate a rollback after the script has finished if AutoCommit is off.
     my $needCleanup = ($Idx =~ /AutoCommit[^\d]+0/) ? 1 : 0;
+    # TODO - Fix mod_perl 2.0 here
     if(!$Rollback{$Idx} and $needCleanup and Apache->can('push_handlers')) {
         print STDERR "$prefix push PerlCleanupHandler \n" if $Apache::DBI::DEBUG > 1;
         Apache->push_handlers("PerlCleanupHandler", \&cleanup);
@@ -196,7 +200,9 @@ Apache::Status->menu_item(
         return \@s;
    }
 
-) if ($INC{'Apache.pm'} and Apache->module('Apache::Status'));
+) if ($INC{'Apache.pm'} and Apache->can('module') and Apache->module('Apache::Status'));
+ 
+
 
 
 1;
@@ -351,6 +357,11 @@ and that mod_perl needs to be configured with the appropriate call-back hooks:
 
   PERL_CHILD_INIT=1 PERL_STACKED_HANDLERS=1. 
 
+=head1 MOD_PERL 2.0
+
+Apache::DBI version 0.90_02 and later might work under mod_perl 2.0.
+See the Changes file for more information.  Also beware that it has
+only been tested very lightly.
 
 =head1 SEE ALSO
 
@@ -365,7 +376,7 @@ the modperl mailinglist, see the mod_perl documentation for
 instructions on how to subscribe).
 
 =item *
-mod_perl by Doug MacEachern <modperl@apache.org>
+mod_perl by Doug MacEachern.
 
 =item *
 DBI by Tim Bunce <dbi-users-subscribe@perl.org>
